==> luma_ml-0.7.1-py3-none-any.whl: luma/__init__.py <==
"""
`Luma`
======

Lumerico's Universal Machine-learning Assistant
-----------------------------------------------
Luma is a comprehensive, user-friendly Python module designed for both beginners 
and advanced users in the field of machine learning and data science. It provides 
a wide range of tools and functionalities to streamline the process of data analysis, 
model building, evaluation, and deployment.

Key Features
------------
- Easy Data Handling: Simplify data preprocessing, transformation, and visualization.
- Model Building: Access a variety of machine learning algorithms.
- Model Evaluation: Utilize robust tools for model validation and tuning.

Getting Started
---------------
To get started with Luma, install the package using `pip`:

```sh
pip install luma-ml
```

After installation, import Luma in your Python script to access its features:

```py
import Luma
```
For detailed documentation, tutorials, and examples, please refer to:
- GitHub: https://github.com/ChanLumerico/luma
- Notion: https://lumerico284.notion.site/LUMA
- PyPI: https://pypi.org/project/luma-ml

For real-world applications, please refer to:

```sh
luma-ml/test/docs/*.py
```
Contribute
----------
Luma is an open-source project, and we welcome contributions from the community. 
Whether you're interested in fixing bugs, adding new features, or improving documentation, 
your help is appreciated.

License
-------
Luma is released under the GPL-3.0 License. See `LICENSE` file for more details.

"""

==> luma_ml-0.9.1-py3-none-any.whl: luma/__init__.py <==
"""
`Luma`
======

Lumerico's Universal Machine-learning Assistant
-----------------------------------------------
Luma is a comprehensive, user-friendly Python library designed for both beginners 
and advanced users in the field of machine learning and data science. It provides 
a wide range of tools and functionalities to streamline the process of data analysis, 
model building, evaluation, and deployment.

Key Features
------------
- Easy Data Handling: Simplify data preprocessing, transformation, and visualization.
- Model Building: Access a variety of machine learning algorithms.
- Model Evaluation: Utilize robust tools for model validation and tuning.

Getting Started
---------------
To get started with Luma, install the package using `pip`:

```sh
pip install luma-ml
```

After installation, import Luma in your Python script to access its features:

```py
import Luma
```
For detailed documentation, tutorials, and examples, please refer to:
- GitHub: https://github.com/ChanLumerico/luma
- Notion: https://lumerico284.notion.site/LUMA
- PyPI: https://pypi.org/project/luma-ml

For real-world applications, please refer to:

```sh
luma-ml/test/docs/*.py
```
Contribute
----------
Luma is an open-source project, and we welcome contributions from the community. 
Whether you're interested in fixing bugs, adding new features, or improving documentation, 
your help is appreciated.

License
-------
Luma is released under the GPL-3.0 License. See `LICENSE` file for more details.

"""
